#
# spec file for package python-jfscripts
#
# Copyright (c) 2025 SUSE LLC
# Copyright (c) 2020, Martin Hauke <mardnh@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_without libalternatives
Name:           python-jfscripts
Version:        1.1.0
Release:        3.1
Summary:        A collection of various tools written by Josef Friedrich
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/Josef-Friedrich/python-scripts
Source:         https://files.pythonhosted.org/packages/source/j/jfscripts/jfscripts-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module poetry}
BuildRequires:  %{python_module wheel}
BuildRequires:  alts
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       alts
Requires:       python-termcolor
Requires:       python-typing-extensions
BuildArch:      noarch
%python_subpackages

%description
A collection of various tools written by Josef Friedrich
  * dns-ipv6-prefix.py
  * extract-pdftext.py
  * find-dupes-by-size.py
  * list-files.py
  * mac-to-eui64.py
  * pdf-compress.py
  * image-into-pdf.py

%prep
%setup -q -n jfscripts-%{version}
find jfscripts/ -name "*.py" -exec sed -i 's|#! %{_bindir}/env python3|#!%{_bindir}/python3|g' {} \;

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand find %{buildroot}/%{$python_sitelib}/jfscripts/ -name "*.py" -exec sed -i -e '/^#!\//, 1d' {} \;
%python_expand cd %{buildroot}%{_bindir} && find . -name "*.py" -exec sh -c 'mv $0 `basename "$0" .py`' '{}' \;
%python_expand %fdupes %{buildroot}%{$python_sitelib}
rm -f %{buildroot}%{_bindir}/_current_flavor
# Prepare for alts usage
for p in dns-ipv6-prefix extract-pdftext find-dupes-by-size image-into-pdf \
    list-files mac-to-eui64 pdf-compress ; do
    %python_clone -a %{buildroot}%{_bindir}/$p
done

#%%check
# Upstream does not provide any tests

%pre
# removing old update-alternatives entries
%python_libalternatives_reset_alternative dns-ipv6-prefix
%python_libalternatives_reset_alternative extract-pdftext
%python_libalternatives_reset_alternative find-dupes-by-size
%python_libalternatives_reset_alternative image-into-pdf
%python_libalternatives_reset_alternative list-files
%python_libalternatives_reset_alternative mac-to-eui64
%python_libalternatives_reset_alternative pdf-compress

%files %{python_files}
%license LICENSE
%doc README.rst
%python_alternative %{_bindir}/dns-ipv6-prefix
%python_alternative %{_bindir}/extract-pdftext
%python_alternative %{_bindir}/find-dupes-by-size
%python_alternative %{_bindir}/list-files
%python_alternative %{_bindir}/mac-to-eui64
%python_alternative %{_bindir}/pdf-compress
%python_alternative %{_bindir}/image-into-pdf
%{python_sitelib}/jfscripts*

%changelog
* Mon Jun  9 2025 Markéta Machová <mmachova@suse.com>
- Convert to libalternatives
* Fri May 30 2025 Markéta Machová <mmachova@suse.com>
- Convert to pip-based build
* Thu Sep 29 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 1.1.0
  * Reformat tox.ini
  * Add some types
  * Add more type hints
  * Bump version 1.0.0
  * Regenerate the README file
  * Get rid of the jflib dependency
  * Remove unused script
  * Fix tests
  * Allow type unions with | in 3.8
  * Run tests on Github actions
  * Reformat using black and isort
  * Add some types
  * Clean up
  * Merge branch 'main' of github.com:Josef-Friedrich/jfscripts
  * Auto commit
  * Regenerate the README
  * Generate the README using the readme-patcher
  * Update dependency to the readme patcher
  * Add README_template.rst
  * Use the version number in pyproject.toml as the single source of truth
  * Remove the u prefix of same strings
  * Unify the use of quotation marks in the file pyproject.toml
  * Replace nose with nose2
  * Place the test files in a folder named `tests`
  * add pyproject.toml
  * Remove more files that belonged to the versioneer
  * Remove versioneer
  * Sort imports using isort
  * Upgrade versioneer
  * Delete obsolete files
  * New option -n, --png
  * Add description
  * Implement --auto-png
  * Use jflib in the tests to import the class “Capturing()”
  * New function: argparser_to_readme()
  * Update setup.py
  * Revert "Test on 3.7"
  * Test on 3.7
  * Fix flake8 issues
  * Add readthedocs badge
* Fri Jan 29 2021 Steve Kowalik <steven.kowalik@suse.com>
- Use python_alternative for all shipped scripts instead of python3_only.
* Sat Mar 21 2020 Martin Hauke <mardnh@gmx.de>
- Initial package, version 0.5.0
